/**
 * Copyright 2007 ZeroTurnaround.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 **/

package org.zeroturnaround.javarebel.support;

import java.io.IOException;
import java.net.URL;
import java.net.URLConnection;
import org.zeroturnaround.javarebel.ClassResource;
import org.zeroturnaround.javarebel.LoggerFactory;


/**
 * A resource for a class loaded from unrecognized resource.
 * 
 * @author Jevgeni Kabanov (ekabanov@zeroturnaround.com)
 */
public class FallbackClassResource implements ClassResource{
  private URL url;
  
  public FallbackClassResource(URL url) {
    this.url = url;
  }
  
  public byte[] getBytes() {
    return null;
  }
  
  public long lastModified() {
    URLConnection con = null;
    try {
      con = url.openConnection();
      return con.getLastModified();
    } catch (IOException e) {
      LoggerFactory.getInstance().error(e);
    }
    finally {
      try {
        if (con != null && con.getInputStream() != null)
          con.getInputStream().close();
      } catch (IOException e) {
        LoggerFactory.getInstance().error(e);
      }
    }
    
    return 0;
  }
  
  public String getPath() {
    return url.getPath();
  }
  
  public String toString() {
    return url.toString();
  }

  public URL toURL() {
    return url;
  }
}
